@@ -1,15 +1,14 @@
-#!/usr/share/ucs-test/runner /usr/bin/py.test -s
+#!/usr/share/ucs-test/runner pytest-3 -s
 ## desc: Run all diagnostic checks
 ## exposure: safe
 ## tags: [basic, apptest]
 ## packages: [univention-management-console-module-diagnostic]
 
-from __future__ import print_function
-
 import subprocess
 import tempfile
-from univention.testing.umc import Client
+
 from univention.testing import utils
+from univention.testing.umc import Client
 
 # One would neeed a strong argument to skip any tests here, as it masks reals problems (See bug #50021)
 SKIPPED_TESTS = []
@@ -21,7 +20,7 @@ def test_run_diagnostic_checks():
 
 	account = utils.UCSTestDomainAdminCredentials()
 	with tempfile.NamedTemporaryFile() as fd:
-		fd.write(account.bindpw)
+		fd.write(account.bindpw.encode('UTF-8'))
 		fd.flush()
 		args = ['/usr/bin/univention-run-diagnostic-checks', '--username', account.username, '--bindpwdfile', fd.name, '-t'] + plugins
 		print(args)
