@@ -1,5 +1,7 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
+#
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
 #
 # Copyright 2013-2022 Univention GmbH
 #
@@ -79,7 +81,7 @@ def get_schema_attribute_id():
 
 
 def call_join_script(join_script_name):
-	print('call_join_script(%r)' % (join_script_name,))
+	print(f'call_join_script({join_script_name!r})')
 	ucr = ConfigRegistry()
 	ucr.load()
 
@@ -89,7 +91,7 @@ def call_join_script(join_script_name):
 
 
 def call_unjoin_script(unjoin_script_name):
-	print('call_unjoin_script(%r)' % (unjoin_script_name,))
+	print(f'call_unjoin_script({unjoin_script_name!r})')
 	ucr = ConfigRegistry()
 	ucr.load()
 
@@ -141,6 +143,6 @@ def get_ldap_master_connection(user_dn):
 
 
 def set_container_description(user_dn, container):
-	print('set_container_description(%r, %r)' % (user_dn, container))
+	print(f'set_container_description({user_dn!r}, {container!r})')
 	lo = get_ldap_master_connection(user_dn)
 	lo.modify(container, [('description', b'', random_name().encode('UTF-8'))])
