@@ -1,7 +1,9 @@
-# -*- coding: utf-8 -*-
 #
 # UCS test
 #
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
 # Copyright 2016-2022 Univention GmbH
 #
 # https://www.univention.de/
@@ -45,7 +47,7 @@ def get_requested_apps():
 				else:
 					pass
 					# utils.fail('Error finding %s' % (line,))
-	except EnvironmentError:
+	except OSError:
 		pass
 		# utils.fail('Error reading %s: %s' % (APPCENTER_FILE, exc))
 	return ret
