@@ -1,5 +1,4 @@
 #!/usr/share/ucs-test/runner pytest-3 -s
-# coding: utf-8
 ## desc: "Test the UCS<->AD sync in {read,write,sync} mode for `con_other_attribute`s."
 ## exposure: dangerous
 ## packages:
@@ -75,7 +74,7 @@ def test_attribute_sync_from_udm_to_ad(attribute, sync_mode):
 
 		# Additional `phone` values must be synced to `otherTelephone`,
 		# `telephoneNumber` must keep its value.
-		print("\nModifying UDM user: {}={}\n".format(ucs_attribute, all_values))
+		print(f"\nModifying UDM user: {ucs_attribute}={all_values}\n")
 		udm.modify_object('users/user', dn=udm_user_dn, set={ucs_attribute: all_values})
 		adconnector.wait_for_sync()
 		AD.verify_object(ad_user_dn, {con_attribute: [primary_value], con_other_attribute: secondary_values})
@@ -84,7 +83,7 @@ def test_attribute_sync_from_udm_to_ad(attribute, sync_mode):
 		# If we delete the first `phone` value via UDM, we want to duplicate
 		# the first value of `otherTelephone` into `telephoneNumber`.
 		(new_primary, next_primary) = secondary_values
-		print("\nModifying UDM user: {}={}\n".format(ucs_attribute, secondary_values))
+		print(f"\nModifying UDM user: {ucs_attribute}={secondary_values}\n")
 		udm.modify_object('users/user', dn=udm_user_dn, set={ucs_attribute: secondary_values})
 		adconnector.wait_for_sync()
 		AD.verify_object(ad_user_dn, {con_attribute: new_primary, con_other_attribute: secondary_values})
@@ -92,7 +91,7 @@ def test_attribute_sync_from_udm_to_ad(attribute, sync_mode):
 
 		# If we delete a `phone` value via UDM that is duplicated in AD, we want
 		# it to be deleted from `telephoneNumber` and `otherTelephone`.
-		print("\nModifying UDM user: {}={}\n".format(ucs_attribute, next_primary))
+		print(f"\nModifying UDM user: {ucs_attribute}={next_primary}\n")
 		udm.modify_object('users/user', dn=udm_user_dn, set={ucs_attribute: next_primary})
 		adconnector.wait_for_sync()
 		AD.verify_object(ad_user_dn, {con_attribute: next_primary, con_other_attribute: next_primary})
@@ -101,7 +100,7 @@ def test_attribute_sync_from_udm_to_ad(attribute, sync_mode):
 		# Setting a completely new `phone` value via UDM, this must be synced
 		# to `telephoneNumber` and `otherTelephone` must be empty.
 		new_phone_who_dis = random_number()
-		print("\nModifying UDM user: {}={}\n".format(ucs_attribute, new_phone_who_dis))
+		print(f"\nModifying UDM user: {ucs_attribute}={new_phone_who_dis}\n")
 		udm.modify_object('users/user', dn=udm_user_dn, set={ucs_attribute: new_phone_who_dis})
 		adconnector.wait_for_sync()
 		AD.verify_object(ad_user_dn, {con_attribute: new_phone_who_dis, con_other_attribute: []})
@@ -109,7 +108,7 @@ def test_attribute_sync_from_udm_to_ad(attribute, sync_mode):
 
 		# No `phone` value via UDM, must result in an empty `telephoneNumber`
 		# and `otherTelephone`.
-		print("\nModifying UDM user: {}={}\n".format(ucs_attribute, []))
+		print(f"\nModifying UDM user: {ucs_attribute}={[]}\n")
 		udm.modify_object('users/user', dn=udm_user_dn, set={ucs_attribute: ''})
 		adconnector.wait_for_sync()
 		AD.verify_object(ad_user_dn, {con_attribute: [], con_other_attribute: []})
@@ -133,7 +132,7 @@ def test_attribute_sync_from_ad_to_udm(attribute, sync_mode):
 		(basic_ad_user, ad_user_dn, udm_user_dn) = create_con_user(AD, udm_user, adconnector.wait_for_sync)
 
 		# Additional values in `otherTelephone` must be appended to `phone`.
-		print("\nModifying AD user: {}={}, {}={}\n".format(con_attribute, primary_value, con_other_attribute, secondary_values))
+		print(f"\nModifying AD user: {con_attribute}={primary_value}, {con_other_attribute}={secondary_values}\n")
 		AD.set_attributes(ad_user_dn, **{con_attribute: [primary_value], con_other_attribute: secondary_values})
 		adconnector.wait_for_sync()
 		tcommon.verify_udm_object("users/user", udm_user_dn, {ucs_attribute: all_values})
@@ -144,7 +143,7 @@ def test_attribute_sync_from_ad_to_udm(attribute, sync_mode):
 			# the first value of `otherTelephone` duplicated into
 			# `telephoneNumber`.
 			(new_primary, _) = secondary_values
-			print("\nModifying AD user: {}={}\n".format(con_attribute, []))
+			print(f"\nModifying AD user: {con_attribute}={[]}\n")
 			AD.set_attributes(ad_user_dn, **{con_attribute: []})
 			adconnector.wait_for_sync()
 			tcommon.verify_udm_object("users/user", udm_user_dn, {ucs_attribute: secondary_values})
@@ -152,7 +151,7 @@ def test_attribute_sync_from_ad_to_udm(attribute, sync_mode):
 
 			# Deleting the duplicate from `otherTelephone` must retain the value of
 			# `telephoneNumber` and `phone` in UDM.
-			print("\nModifying AD user: {}={}\n".format(con_other_attribute, []))
+			print(f"\nModifying AD user: {con_other_attribute}={[]}\n")
 			AD.set_attributes(ad_user_dn, **{con_other_attribute: []})
 			adconnector.wait_for_sync()
 			tcommon.verify_udm_object("users/user", udm_user_dn, {ucs_attribute: new_primary})
@@ -161,7 +160,7 @@ def test_attribute_sync_from_ad_to_udm(attribute, sync_mode):
 		# Setting a new `telephoneNumber` and no `otherTelephone` in AD must
 		# result in a single new value in `phone`.
 		new_phone_who_dis = random_number()
-		print("\nModifying AD user: {}={}\n".format(con_attribute, new_phone_who_dis))
+		print(f"\nModifying AD user: {con_attribute}={new_phone_who_dis}\n")
 		AD.set_attributes(ad_user_dn, **{con_attribute: new_phone_who_dis, con_other_attribute: []})
 		adconnector.wait_for_sync()
 		tcommon.verify_udm_object("users/user", udm_user_dn, {ucs_attribute: new_phone_who_dis})
@@ -169,7 +168,7 @@ def test_attribute_sync_from_ad_to_udm(attribute, sync_mode):
 
 		# Setting no `telephoneNumber` and no `otherTelephone` in AD must
 		# result in no value in `phone`.
-		print("\nModifying AD user: {}={}\n".format(con_attribute, []))
+		print(f"\nModifying AD user: {con_attribute}={[]}\n")
 		AD.set_attributes(ad_user_dn, **{con_attribute: [], con_other_attribute: []})
 		adconnector.wait_for_sync()
 		tcommon.verify_udm_object("users/user", udm_user_dn, {ucs_attribute: []})
