@@ -1,5 +1,7 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
+#
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
 #
 # Copyright 2019-2022 Univention GmbH
 #
@@ -27,7 +29,7 @@
 # License with the Debian GNU/Linux or Univention distribution in file
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
-"""Grep python tracebacks in logfiles"""
+"""Grep Python tracebacks in logfiles"""
 
 import argparse
 import collections
@@ -45,7 +47,7 @@ RE_APPCENTER = re.compile(r'^(\s+\d+ .*[\d \-:]+ \[(    INFO| WARNING|   DEBUG|
 class Tracebacks(set):
 
 	def __init__(self, *args, **kwargs):
-		super(Tracebacks, self).__init__(*args, **kwargs)
+		super().__init__(*args, **kwargs)
 		self.occurred = 0
 		self.filenames = set()
 
@@ -180,6 +182,10 @@ COMMON_EXCEPTIONS = (
 	E(r'^univention.admin.uexceptions.noObject: No such object$', ['^  File "/usr/lib/python3/dist-packages/univention/admin/objects.py", line .*, in get']),  # s4c
 	# during upgrade to UCS 5.0-2
 	E("^AttributeError: 'PortalsPortalEntryObjectProperties' object has no attribute 'keywords'", ['reloader.py.*in refresh'], (54295,)),
+	E("ImportError: cannot import name '_ldap_cache' from 'univention.admin'", ['in update'], (54853,)),
+	E(r'ConnectionResetError: \[Errno 104\] Connection reset by peer', ['urllib3']),
+	E(r"urllib3.exceptions.ProtocolError: \('Connection aborted.', ConnectionResetError\(104, 'Connection reset by peer'\)\)", "urllib3"),
+	E(r"requests.exceptions.ConnectionError: \('Connection aborted.', ConnectionResetError\(104, 'Connection reset by peer'\)\)", ['univention-directory-listener/system/monitoring-client.py']),
 	# during upgrade to UCS 5.0-0
 	E("^(apt.cache.FetchFailedException|apt_pkg.Error): E:The repository 'http://localhost/univention-repository.* Release' is not signed."),
 	E('ImportError: No module named client', [
@@ -197,7 +203,7 @@ COMMON_EXCEPTIONS = (
 	E("ssl.SSLCertVerificationError.*self signed certificate in certificate chain", ['univention/lib/umc.py.*in send'], 53670),
 	E("univention.lib.umc.ConnectionError: .*Could not send request.*SSLCertVerificationError", ['univention-self-service-invitation'], 53670),
 	E("FileNotFoundError: \\[Errno 2\\] No such file or directory: '/etc/machine.secret'", ['univention/lib/umc.py.*in authenticate_with_machine_account'], 53670),
-	E("TypeError: modify\(\) got an unexpected keyword argument 'rename_callback'", ['_register_app'], 54578),
+	E(r"TypeError: modify\(\) got an unexpected keyword argument 'rename_callback'", ['_register_app'], 54578),
 	# during UCS 5.0-0-errata updates
 	E(r"TypeError: __init__\(\) got an unexpected keyword argument 'cli_enabled'", ['_register_app'], 54584),
 
@@ -267,6 +273,8 @@ COMMON_EXCEPTIONS = (
 	E(r"IOError: \[Errno 2\] No such file or directory: u'/etc/ucsschool-import/(postgres|django_key).secret'", ['gunicorn'], 53750),
 	E("ImportError: Error accessing LDAP via machine account: {'desc': 'Invalid credentials'}", ['univention-directory-listener/system/ucsschool-s4-branch-site.py']),
 	E("ldap.CONSTRAINT_VIOLATION: .*unique index violation on objectSid", ['in sync_from_ucs'], 43775),  # a test creates a user with the default Administrators SID, which creates a SID-Conflict
+	E("ucsschool.importer.exceptions.UnknownRole: Unknown role 'triggererror' found in 'Typ' column.", ['csv_reader.py']),
+	E("KeyError: 'triggererror'", ['csv_reader.py']),
 	# Tracebacks caused by specific UCS bugs:
 	E(r'^ldap\.NO_SUCH_OBJECT: .*', [r'quota\.py'], 52765),
 	E(r'.*OperationalError.*FATAL:.*admindiary.*', [r'admindiary_backend_wrapper\.py', '_wrap_pool_connect'], 51671),
@@ -333,6 +341,7 @@ COMMON_EXCEPTIONS = (
 	# Tracebacks caused by specific UCS@school bugs:
 	E(r"_ldb.LdbError: \(1, 'LDAP client internal error: NT_STATUS_INVALID_PARAMETER'\)", ['univention-samba4-site-tool.py'], 54592),
 	E(r"AssertionError: Attribute \(username\) is parsed wrong as.*", ['103_ucsschool_smbstatus_parser.py'], 54591),
+	E(r"optparse.OptionConflictError: option.*authentication-file", ['univention-samba4-site-tool.py'], 55082),
 )
 
 
