@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
@@ -41,14 +40,15 @@ Univention common Python library to manage connections to remote |UMC| servers.
 >>> umc.umc_logout()
 """
 
+import base64
 import json
 import locale
 import ssl
+import http.client
 from http.cookies import SimpleCookie
 from http.client import HTTPSConnection, HTTPException
 from typing import Any, Dict, List, Optional, Tuple, Type, TypeVar, Union  # noqa: F401
 
-from six.moves import http_client as httplib
 
 from univention.config_registry import ConfigRegistry
 
@@ -97,7 +97,7 @@ class ConnectionError(Exception):
 
 	def __init__(self, msg, reason=None):
 		# type: (str, Exception) -> None
-		super(ConnectionError, self).__init__(msg, reason)
+		super().__init__(msg, reason)
 		self.reason = reason
 
 
@@ -107,7 +107,7 @@ class HTTPError(Exception):
 	A specialized sub-class if automatically instantiated based on the |HTTP| return code.
 
 	:param request: The |HTTP| request.
-	:param httplib.HTTPResponse response: The |HTTP| response.
+	:param http.client.HTTPResponse response: The |HTTP| response.
 	:param str hostname: The host name of the failed server.
 	"""
 	__metaclass__ = _HTTPType
@@ -150,7 +150,7 @@ class HTTPError(Exception):
 
 	def __new__(cls, request, response, hostname):
 		err = cls.codes.get(response.status, cls)
-		return super(HTTPError, cls).__new__(err, request, response, hostname)  # type: ignore
+		return super().__new__(err, request, response, hostname)  # type: ignore
 
 	def __init__(self, request, response, hostname):
 		self.request = request
@@ -158,88 +158,94 @@ class HTTPError(Exception):
 		self.response = response
 
 	def __repr__(self):
-		return '<HTTPError %s>' % (self,)
+		return f'<HTTPError {self}>'
 
 	def __str__(self):
-		return '%s on %s (%s): %s' % (self.status, self.hostname, self.request.path, self.response.body)
+		# type: () -> str
+		traceback = ''
+		data = self.response.data
+		if self.status >= 500 and isinstance(self.response.data, dict) and isinstance(self.response.data.get('traceback'), str) and 'Traceback (most recent call last)' in self.response.data['traceback']:
+			data = data.copy()
+			traceback = '\n{}'.format(data.pop('traceback'))
+		return f'{self.status} on {self.hostname} ({self.request.path}): {data}{traceback}'
 
 
 class HTTPRedirect(HTTPError):
-	""":py:data:`httplib.MULTIPLE_CHOICES` |HTTP|/1.1, :rfc:`2616`, Section 10.3.1"""
+	""":py:data:`http.client.MULTIPLE_CHOICES` |HTTP|/1.1, :rfc:`2616`, Section 10.3.1"""
 	code = 300
 
 
 class MovedPermanently(HTTPRedirect):
-	""":py:data:`httplib.MOVED_PERMANENTLY` |HTTP|/1.1, :rfc:`2616`, Section 10.3.2"""
+	""":py:data:`http.client.MOVED_PERMANENTLY` |HTTP|/1.1, :rfc:`2616`, Section 10.3.2"""
 	code = 301
 
 
 class Found(HTTPRedirect):
-	""":py:data:`httplib.FOUND` |HTTP|/1.1, :rfc:`2616`, Section 10.3.3"""
+	""":py:data:`http.client.FOUND` |HTTP|/1.1, :rfc:`2616`, Section 10.3.3"""
 	code = 302
 
 
 class SeeOther(HTTPRedirect):
-	""":py:data:`httplib.SEE_OTHER` |HTTP|/1.1, :rfc:`2616`, Section 10.3.4"""
+	""":py:data:`http.client.SEE_OTHER` |HTTP|/1.1, :rfc:`2616`, Section 10.3.4"""
 	code = 303
 
 
 class NotModified(HTTPRedirect):
-	""":py:data:`httplib.NOT_MODIFIED` |HTTP|/1.1, :rfc:`2616`, Section 10.3.5"""
+	""":py:data:`http.client.NOT_MODIFIED` |HTTP|/1.1, :rfc:`2616`, Section 10.3.5"""
 	code = 304
 
 
 class BadRequest(HTTPError):
-	""":py:data:`httplib.BAD_REQUEST` |HTTP|/1.1, :rfc:`2616`, Section 10.4.1"""
+	""":py:data:`http.client.BAD_REQUEST` |HTTP|/1.1, :rfc:`2616`, Section 10.4.1"""
 	code = 400
 
 
 class Unauthorized(HTTPError):
-	""":py:data:`httplib.UNAUTHORIZED` |HTTP|/1.1, :rfc:`2616`, Section 10.4.2"""
+	""":py:data:`http.client.UNAUTHORIZED` |HTTP|/1.1, :rfc:`2616`, Section 10.4.2"""
 	code = 401
 
 
 class Forbidden(HTTPError):
-	""":py:data:`httplib.UNAUTHORIZED` |HTTP|/1.1, :rfc:`2616`, Section 10.4.4"""
+	""":py:data:`http.client.UNAUTHORIZED` |HTTP|/1.1, :rfc:`2616`, Section 10.4.4"""
 	code = 403
 
 
 class NotFound(HTTPError):
-	""":py:data:`httplib.NOT_FOUND` |HTTP|/1.1, :rfc:`2616`, Section 10.4.5"""
+	""":py:data:`http.client.NOT_FOUND` |HTTP|/1.1, :rfc:`2616`, Section 10.4.5"""
 	code = 404
 
 
 class MethodNotAllowed(HTTPError):
-	""":py:data:`httplib.METHOD_NOT_ALLOWED` |HTTP|/1.1, :rfc:`2616`, Section 10.4.6"""
+	""":py:data:`http.client.METHOD_NOT_ALLOWED` |HTTP|/1.1, :rfc:`2616`, Section 10.4.6"""
 	code = 405
 
 
 class NotAcceptable(HTTPError):
-	""":py:data:`httplib.NOT_ACCEPTABLE` |HTTP|/1.1, :rfc:`2616`, Section 10.4.7"""
+	""":py:data:`http.client.NOT_ACCEPTABLE` |HTTP|/1.1, :rfc:`2616`, Section 10.4.7"""
 	code = 406
 
 
 class UnprocessableEntity(HTTPError):
-	""":py:data:`httplib.UNPROCESSABLE_ENTITY` WEBDAV, :rfc:`22518`, Section 10.3"""
+	""":py:data:`http.client.UNPROCESSABLE_ENTITY` WEBDAV, :rfc:`22518`, Section 10.3"""
 	code = 422
 
 
 class InternalServerError(HTTPError):
-	""":py:data:`httplib.INTERNAL_SERVER_ERROR` |HTTP|/1.1, :rfc:`2616`, Section 10.5.1"""
+	""":py:data:`http.client.INTERNAL_SERVER_ERROR` |HTTP|/1.1, :rfc:`2616`, Section 10.5.1"""
 	code = 500
 
 
 class BadGateway(HTTPError):
-	""":py:data:`httplib.BAD_GATEWAY` |HTTP|/1.1, :rfc:`2616`, Section 10.5.3"""
+	""":py:data:`http.client.BAD_GATEWAY` |HTTP|/1.1, :rfc:`2616`, Section 10.5.3"""
 	code = 502
 
 
 class ServiceUnavailable(HTTPError):
-	""":py:data:`httplib.SERVICE_UNAVAILABLE` |HTTP|/1.1, :rfc:`2616`, Section 10.5.4"""
+	""":py:data:`http.client.SERVICE_UNAVAILABLE` |HTTP|/1.1, :rfc:`2616`, Section 10.5.4"""
 	code = 503
 
 
-class Request(object):
+class Request:
 	"""
 	The |HTTP| request.
 
@@ -257,19 +263,19 @@ class Request(object):
 		self.headers = headers or {}
 
 	def get_body(self):
-		# type: () -> Union[str, dict, None]
+		# type: () -> Optional[bytes]
 		"""
 		Return the request data.
 
-		:returns: |JSON| data is returned as a dictionary, all other as raw.
-		:rtype: dict or str
+		:returns: encodes data in JSON if Content-Type wants it
+		:rtype: bytes
 		"""
 		if self.headers.get('Content-Type', '').startswith('application/json'):
-			return json.dumps(self.data)
+			return json.dumps(self.data).encode('ASCII')
 		return self.data
 
 
-class Response(object):
+class Response:
 	"""
 	The |HTTP| response.
 
@@ -277,7 +283,7 @@ class Response(object):
 	:param str reason: string with the reason phrase e.g. 'OK'
 	:param bytes body: the raw response body
 	:param list headers: the response headers as list of tuples
-	:param httplib.HTTPResponse _response: The original |HTTP| response.
+	:param http.client.HTTPResponse _response: The original |HTTP| response.
 	"""
 
 	@property
@@ -303,7 +309,7 @@ class Response(object):
 			return self.data.get('message')
 
 	def __init__(self, status, reason, body, headers, _response):
-		# type: (int, str, bytes, List[Tuple[str, str]], httplib.HTTPResponse) -> None
+		# type: (int, str, bytes, List[Tuple[str, str]], http.client.HTTPResponse) -> None
 		self.status = status
 		self.reason = reason
 		self.body = body
@@ -334,24 +340,24 @@ class Response(object):
 		data = self.body
 		if self.get_header('Content-Type', '').startswith('application/json'):
 			try:
-				data = json.loads(data.decode('utf-8'))
+				data = json.loads(data.decode('UTF-8'))
 			except ValueError as exc:
-				raise ConnectionError('Malformed response data: %r' % (data,), reason=exc)
+				raise ConnectionError(f'Malformed response data: {data!r}', reason=exc)
 		return data
 
 	@classmethod
 	def _from_httplib_response(cls, response):
-		# type: (httplib.HTTPResponse) -> Response
+		# type: (http.client.HTTPResponse) -> Response
 		"""
 		Create class instance from |HTTP| response.
 
-		:param httplib.HTTPResponse response: The |HTTP| response.
+		:param http.client.HTTPResponse response: The |HTTP| response.
 		"""
 		data = response.read()
 		return cls(response.status, response.reason, data, response.getheaders(), response)
 
 
-class Client(object):
+class Client:
 	"""
 	A client capable to speak with a |UMC| server.
 
@@ -381,12 +387,13 @@ class Client(object):
 		self._raise_errors = True
 		self._automatic_reauthentication = automatic_reauthentication
 		self.cookies = {}  # type: Dict[str, str]
-		self.username = username
-		self.password = password
+		self.username = username or ''
+		self.password = password or ''
 		if username:
-			self.authenticate(username, password)
+			self.authenticate(self.username, self.password)
 
 	def authenticate(self, username, password):
+		# type: (str, str) -> Response
 		"""
 		Authenticate against the host and preserves the
 		cookie. Has to be done only once (but keep in mind that the
@@ -400,9 +407,9 @@ class Client(object):
 		return self.umc_auth(username, password)
 
 	def reauthenticate(self):
-		# type: () -> None
+		# type: () -> Response
 		"""
-		Re-authenticate using the stores username and password.
+		Re-authenticate using the stored username and password.
 		"""
 		return self.authenticate(self.username, self.password)
 
@@ -414,7 +421,7 @@ class Client(object):
 		:param str username: A user name.
 		:param str password: The password of the user.
 		"""
-		self._headers['Authorization'] = 'Basic %s' % ('%s:%s' % (username, password)).encode('base64').rstrip().decode('ascii')
+		self._headers['Authorization'] = 'Basic %s' % (base64.b64encode(b'%s:%s' % (username.encode('UTF-8'), password.encode('UTF-8'))).decode('ASCII'),)
 
 	def authenticate_saml(self, username, password):
 		# type: (str, str) -> None
@@ -440,7 +447,7 @@ class Client(object):
 		try:
 			with open('/etc/machine.secret') as machine_file:
 				password = machine_file.readline().strip()
-		except EnvironmentError as exc:
+		except OSError as exc:
 			raise ConnectionError('Could not read /etc/machine.secret', reason=exc)
 		self.authenticate(username, password)
 
@@ -457,7 +464,7 @@ class Client(object):
 		:rtype: Response
 		"""
 		data = self.__build_data(options, flavor)
-		return self.request('POST', 'command/%s' % (path,), data, headers)
+		return self.request('POST', f'command/{path}', data, headers)
 
 	def umc_set(self, options, headers=None):
 		# type: (Optional[dict], Optional[dict]) -> Response
@@ -561,7 +568,7 @@ class Client(object):
 			request.headers['X-XSRF-Protection'] = self.cookies['UMCSessionId']
 		try:
 			response = self.__request(request)
-		except (HTTPException, EnvironmentError, ssl.CertificateError) as exc:
+		except (HTTPException, OSError, ssl.CertificateError) as exc:
 			raise ConnectionError('Could not send request.', reason=exc)
 		self._handle_cookies(response)
 		response = Response._from_httplib_response(response)
@@ -570,11 +577,11 @@ class Client(object):
 		return response
 
 	def _handle_cookies(self, response):
-		# type: (httplib.HTTPResponse) -> None
+		# type: (http.client.HTTPResponse) -> None
 		"""
 		Parse cookies from |HTTP| response and store for next request.
 
-		:param httplib.HTTPResponse response: The |HTTP| response.
+		:param http.client.HTTPResponse response: The |HTTP| response.
 		"""
 		# FIXME: this cookie handling doesn't respect path, domain and expiry
 		cookies = SimpleCookie()  # type: SimpleCookie[Any]
@@ -582,15 +589,15 @@ class Client(object):
 		self.cookies.update({cookie.key: cookie.value for cookie in cookies.values()})
 
 	def __request(self, request):
-		# type: (Request) -> httplib.HTTPResponse
+		# type: (Request) -> http.client.HTTPResponse
 		"""
 		Perform a request to the |UMC| server and return its response.
 
 		:param Request request: The |UMC| request.
 		:returns: The |HTTP| response.
-		:rtype: httplib.HTTPResponse
+		:rtype: http.client.HTTPResponse
 		"""
-		uri = '%s%s' % (self._base_uri, request.path)
+		uri = f'{self._base_uri}{request.path}'
 		con = self._get_connection()
 		con.request(request.method, uri, request.get_body(), headers=request.headers)
 		response = con.getresponse()
@@ -618,7 +625,7 @@ class Client(object):
 		return self.ConnectionType(self.hostname, timeout=self._timeout)
 
 	def __build_data(self, data, flavor=None):
-		# type: (Optional[dict], Optional[str]) -> Dict[str, Any]
+		# type: (Optional[Dict[str, Any]], Optional[str]) -> Dict[str, Any]
 		"""
 		Create a dictionary as expected by the |UMC| Server.
 
