@@ -1,4 +1,3 @@
-# vim: set fileencoding=utf-8 ft=python sw=4 ts=4 :
 """Public interface for test resultes."""
 
 from typing import Dict, Optional  # noqa: F401
@@ -6,7 +5,7 @@ from typing import Dict, Optional  # noqa: F401
 __all__ = ['TestCodes']
 
 
-class TestCodes(object):
+class TestCodes:
 
 	"""Public interface for test resultes."""
 	RESULT_OKAY = 0
